@@ -3,14 +3,14 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.1" or
-    raise "ruby lib version (1.8.1) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.2" or
+    raise "ruby lib version (1.8.2) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/i386\-cygwin\Z', '')
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.1/ruby"
+  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.2/ruby"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -43,7 +43,7 @@ module Config
   CONFIG["LIBS"] = ""
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
-  CONFIG["TEENY"] = "1"
+  CONFIG["TEENY"] = "2"
   CONFIG["build"] = "i586-pc-linux-gnu"
   CONFIG["build_cpu"] = "i586"
   CONFIG["build_vendor"] = "pc"
@@ -80,7 +80,7 @@ module Config
   CONFIG["ac_ct_DLLWRAP"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
-  CONFIG["LIBOBJS"] = " crypt$(U).o flock$(U).o strftime$(U).o"
+  CONFIG["LIBOBJS"] = " crypt$(U).o strftime$(U).o"
   CONFIG["ALLOCA"] = ""
   CONFIG["DLDFLAGS"] = " -Wl,--enable-auto-import,--export-all"
   CONFIG["ARCH_FLAG"] = ""
@@ -91,14 +91,16 @@ module Config
   CONFIG["DLEXT2"] = "dll"
   CONFIG["LIBEXT"] = "a"
   CONFIG["LINK_SO"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
+  CONFIG["LIBPATHFLAG"] = " -L\"%s\""
   CONFIG["RPATHFLAG"] = ""
+  CONFIG["TRY_LINK"] = ""
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.1/c.obj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.2/c.obj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["ARCHFILE"] = ""
+  CONFIG["RDOCTARGET"] = ""
   CONFIG["XCFLAGS"] = ""
   CONFIG["XLDFLAGS"] = " -Wl,--stack,0x02000000 -L."
   CONFIG["LIBRUBY_LDSHARED"] = "gcc -shared -s"
@@ -126,10 +128,10 @@ module Config
   CONFIG["arch"] = "i386-cygwin"
   CONFIG["sitearch"] = "i386-cygwin"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "'--cache=config.cache' '--target=i386-cygwin' '--host=i686-pc-cygwin' '--build=i586-pc-linux-gnu' '--program-prefix=' '--includedir=/usr/local/cygwin-local/include' '--with-curses-dir=/usr/local/cygwin-local/ncurses' '--with-opt-dir=/usr/local/cygwin-local' '--with-dbm-type=gdbm' '--with-gcc=gcc' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i686-pc-cygwin' 'target_alias=i386-cygwin'"
+  CONFIG["configure_args"] = "'--cache=config.cache' '--target=i386-cygwin' '--host=i686-pc-cygwin' '--build=i586-pc-linux-gnu' '--program-prefix=' '--includedir=/usr/local/cygwin-local/include' '--with-curses-dir=/usr/local/cygwin-local/ncurses' '--with-opt-dir=/usr/local/cygwin-local' '--with-bundled-md5' '--disable-tcl-thread' '--with-dbm-type=gdbm' '--enable-tcltk_stubs' '--with-tcllib=tclstub' '--with-tklib=tkstub' '--with-gcc=gcc' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i686-pc-cygwin' 'target_alias=i386-cygwin'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
-  CONFIG["LTLIBOBJS"] = " crypt$(U).lo flock$(U).lo strftime$(U).lo"
+  CONFIG["LTLIBOBJS"] = " crypt$(U).lo strftime$(U).lo"
   CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
   CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
   CONFIG["builddir"] = "$(ac_builddir)"
@@ -141,7 +143,7 @@ module Config
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
-  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.1/c.obj"
+  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.2/c.obj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val, config = CONFIG)
